use std::process::{Stdio, Command};

use crate::common;
use crate::bar_modules;

#[derive(Clone)]
pub struct UnibarModuleMusic {
    pub opts: common::AppOptions,
}

impl bar_modules::BarModuleActions for UnibarModuleMusic {

    // --------------------
    fn get(&self) -> String {
        let mut parts = Vec::new();

        // MPD format options here:
        //   https://manpages.ubuntu.com/manpages/plucky/man1/mpc.1.html
        let current_output = Command::new("mpc")
                            .arg("--format")
                            .arg("[%artist% - ][%title%]")
                            .arg("current")
                            .stdout(Stdio::piped())
                            .output()
                            .unwrap();
        let mut current_stdout = String::from_utf8(current_output.stdout).unwrap();
        current_stdout.pop();
        parts.push(format!("{}", current_stdout));

        if self.opts.music_progress {
            let progress_output = Command::new("mpc")
                                .arg("status")
                                .arg("%percenttime% %totaltime%")
                                .stdout(Stdio::piped())
                                .output()
                                .unwrap();
            let mut progress_stdout = String::from_utf8(progress_output.stdout).unwrap();
            progress_stdout.pop();
            parts.push(format!("[{}]", progress_stdout));
        }

        return format!("{}", parts.join(" "));
    }
}
